annotation

# XMLRésuméLibrary: User Guide

address | Element Reference | artTitle

## Name

annotation — Additional information about a degree

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `annotation` element provides additional information about an academic degree. It could be used to describe special honors (“Graduated summa cum laude”) or circumstances (“Completed degree in one year in accelerated program”).

### Parents

`annotation` may be contained in these elements: `degree`

## Examples

    <degree>
      <level>BS</level>
      <major>Street Cleaning Technology</major>
      <annotation>
        Graduated with highest honors.
      </annotation>
    </degree>

    <degree>
      <level>BFA</level>
      <major>Chalkboard Scratching Composition</major>
      <annotation>
        Received dean's award in 1984.
      </annotation>
    </degree>

address | Element Reference | artTitle